#[repr(C)]pub struct caca_event {
pub _address: u8,
}Expand description
\brief Handling of user events.
This structure is filled by caca_get_event() when an event is received. It is an opaque structure that should only be accessed through caca_event_get_type() and similar functions. The struct members may no longer be directly accessible in future versions.
Fields
_address: u8Trait Implementations
Sourceimpl Clone for caca_event
impl Clone for caca_event
Sourcefn clone(&self) -> caca_event
fn clone(&self) -> caca_event
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for caca_event